  function f = f_streuung(t,z)

% function f = f_streuung(t,z)
%
% Zweck: Berechne rechte Seite fuer Streuung im Lennard-Jones Potential
%        Diff.-Gl.
%
% Parameters: t ... Zeit
%             z ... Loseungsvektor (Beachte Konvention in den Notes unten!)
%
% Returns: f ... rechte Seite fuer Streuung
%
% Notes: Wir verwenden folgende Konvention
%
%          z(t) = [x(t),vx(t),y(t),vy(t)]^T
%
%        und damit fuer die rechte Seite
%
%          f(t,z(t)) = [vx(t),-gradU_x,vy(t),-gradU_y]^T
%
%        Anstatt y fuer den Loesungsvektor verwenden wir z um Verwechslungen
%        mit der y-Koordinate des Teilchens zu vermeiden
%

% berechne x- & y-Komponenten von grad(U)
  r2 = z(1)^2 + z(3)^2;
  gradU_x = 4.*(6./r2^4 - 12./r2^7).*z(1);
  gradU_y = 4.*(6./r2^4 - 12./r2^7).*z(3);

% berechne rechte Seite der Diff.-Gl.
  f = zeros(size(z));
  f = [z(2),-gradU_x,z(4),-gradU_y]';
